import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Comparator;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.StringTokenizer;

/**
 * CTU Open Contest 2014
 * Problem solution: Picture Validator
 * 
 * The symbols are normalized as follows:
 * <ol>
 * <li>coordinates are shifted so that left=0, bottom=0
 * <li>line segments are grouped by a line they lie at
 * <li>for each line, touching and overlapping segments are merged
 * </ol>
 * 
 * After this normalization, it is easy to compare and count symbols
 * using standard Java mechanisms.
 * 
 * @author Martin Kacer
 */
public class validate {
	StringTokenizer st = new StringTokenizer("");
	BufferedReader input = new BufferedReader(new InputStreamReader(System.in));
	boolean hasNextToken() throws Exception {
		while (!st.hasMoreTokens()) {
			String line = input.readLine();
			if (line == null) return false;
			st = new StringTokenizer(line);
		}
		return true;
	}
	String nextToken() throws Exception {
		return (!hasNextToken()) ? null : st.nextToken();
	}
	int nextInt() throws Exception {
		return Integer.parseInt(nextToken());
	}
	public static void main(String[] args) throws Exception {
		validate instance = new validate();
		while (instance.hasNextToken()) instance.run();
	}
	
	static class Pair {
		int a, b;
		Pair(int a, int b) { this.a = a; this.b = b; }
		@Override public int hashCode() {
			return (31 + a) * 100019 + b;
		}
		@Override public boolean equals(Object obj) {
			if (this == obj) return true;
			if (!(obj instanceof Pair)) return false;
			Pair op = (Pair)obj;
			return (this.a == op.a && this.b == op.b);
		}
		@Override public String toString() { return "("+a+','+b+')'; }
	}
	Comparator<Pair> COMPARE_BY_A = new Comparator<Pair>() {
		public int compare(Pair o1, Pair o2) {
			return o1.a - o2.a;
		}
	};

	/** This class serves either as a line segment (giving its two endpoints)
	 * or it specifies a line: a1/b1 being its direction, a2/b2 position.
	 */
	static class PairPair {
		int a1, b1, a2, b2;
		PairPair(int a1, int b1, int a2, int b2) { this.a1 = a1; this.b1 = b1; this.a2 = a2; this.b2 = b2; }
		@Override public int hashCode() {
			return (((31 + a1) * 100019 + b1) * 100019 + a2) * 100019 + b2;
		}
		@Override public boolean equals(Object obj) {
			if (this == obj) return true;
			if (!(obj instanceof PairPair)) return false;
			PairPair op = (PairPair)obj;
			return (this.a1 == op.a1 && this.b1 == op.b1 && this.a2 == op.a2 && this.b2 == op.b2);
		}
		@Override public String toString() { return "("+a1+','+b1+';'+a2+','+b2+')'; }
	}

	static final int MAX = 10000;

	/** input segments (instance field, so it may be reused) */
	List<PairPair> segments = new ArrayList<PairPair>(MAX*2);

	void run() throws Exception {
		System.out.println(readNormalized().equals(readNormalized()) ? "YES" : "NO");
	}

	/** Reads one symbol from the input and returns its normalized data. */
	Map<PairPair,Set<Pair>> readNormalized() throws Exception {
		if (!hasNextToken()) return null;
		segments.clear();
		int ax = 0, ay = 0, mx = Integer.MAX_VALUE, my = Integer.MAX_VALUE;
		// read all input segments
		int n = nextInt();
		for (int i = 0; i < n; ++i) {
			String x = nextToken();
			if ("M".equals(x)) {
				ax += nextInt(); ay += nextInt();
				continue;
			}
			int xd = nextInt(), yd = nextInt();
			if (ax < mx) mx = ax; if (ay < my) my = ay;
			segments.add(new PairPair(ax, ay, ax+xd, ay+yd));
			ax += xd; ay += yd;
			if (ax < mx) mx = ax; if (ay < my) my = ay;
		}
		// first of all, shift the image so that its bottom-left corner is at (0,0)
		for (PairPair p : segments) { p.a1 -= mx; p.b1 -= my; p.a2 -= mx; p.b2 -= my; }
		return normalize(categorize(segments));
	}

	/** @param segs list of segments (each two pairs represent one)
	 *  @return key is direction; it maps to the list of intervals covered by segments
	 */
	Map<PairPair,Set<Pair>> categorize(List<PairPair> segs) {
		Map<PairPair,Set<Pair>> cat = new HashMap<PairPair,Set<Pair>>();
		for (PairPair pp : segs) {
			int xd = pp.a2 - pp.a1, yd = pp.b2 - pp.b1;
			int pa, pb; // position of the line
			if (xd == 0 && yd == 0) continue;
			else if (xd == 0) {
				yd = 1; pa = pp.a1; pb = 0; pp.a1 = pp.b1; pp.a2 = pp.b2;
			} else if (yd == 0) {
				xd = 1; pa = 0; pb = pp.b1;
			} else {
				if (xd < 0) { xd = -xd; yd = -yd; }
				int g = gcd(xd, Math.abs(yd)); xd /= g; yd /= g;
				pa = pp.b1 * xd - pp.a1 * yd; pb = xd;
				g = gcd(Math.abs(pa), pb); pa /= g; pb /= g;
			}
			PairPair dir = new PairPair(xd, yd, pa, pb);
			Pair val = (pp.a1 < pp.a2) ? new Pair(pp.a1, pp.a2) : new Pair(pp.a2, pp.a1);
			Set<Pair> dirset = cat.get(dir);
			if (dirset == null) { cat.put(dir, dirset = new HashSet<Pair>()); }
			dirset.add(val);
		}
		return cat;
	}

	/**
	 * @return the same as input but all neighboring and touching segments are merged into one
	 */
	Map<PairPair,Set<Pair>> normalize(Map<PairPair,Set<Pair>> cat) {
		for (Set<Pair> intervals : cat.values()) {
			Pair[] ia = intervals.toArray(new Pair[intervals.size()]);
			Arrays.sort(ia, COMPARE_BY_A);
			intervals.clear();
			int cur1 = Integer.MIN_VALUE, cur2 = Integer.MIN_VALUE;
			for (Pair i : ia) {
				if (cur2 < i.a) {
					if (cur1 < cur2) intervals.add(new Pair(cur1, cur2));
					cur1 = i.a; cur2 = i.b;
				} else {
					if (i.b > cur2) cur2 = i.b;
				}
			}
			if (cur1 < cur2) intervals.add(new Pair(cur1, cur2));
		}
		return cat;
	}

	static int gcd(int a, int b) {
		int bb;
		while (b > 0) {
			bb = b; b = a % b; a = bb;
		}
		return a;
	}
}
